pub struct SerialPortInfo {
pub serial_class: Class,
pub serial_vid: u32,
pub serial_pid: u32,
}Fields
serial_class: Classserial_vid: u32serial_pid: u32Trait Implementations
Sourceimpl Clone for SerialPortInfo
impl Clone for SerialPortInfo
Sourcefn clone(&self) -> SerialPortInfo
fn clone(&self) -> SerialPortInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SerialPortInfo
Sourceimpl Debug for SerialPortInfo
impl Debug for SerialPortInfo
Sourceimpl<___E> Encode<SerialPortInfo, ___E> for SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SerialPortInfo, ___E> for SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SerialPortInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SerialPortInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<SerialPortInfo, ___E> for &'a SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SerialPortInfo, ___E> for &'a SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SerialPortInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SerialPortInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SerialPortInfo>, ___E> for SerialPortInfo
impl<___E> EncodeOption<Box<'static, SerialPortInfo>, ___E> for SerialPortInfo
Sourcefn encode_option(
this: Option<SerialPortInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SerialPortInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SerialPortInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SerialPortInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SerialPortInfo>, ___E> for &'a SerialPortInfo
impl<'a, ___E> EncodeOption<Box<'static, SerialPortInfo>, ___E> for &'a SerialPortInfo
Sourcefn encode_option(
this: Option<&'a SerialPortInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SerialPortInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SerialPortInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SerialPortInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SerialPortInfo
Sourceimpl FromWire<SerialPortInfo> for SerialPortInfo
impl FromWire<SerialPortInfo> for SerialPortInfo
Sourcefn from_wire(wire: SerialPortInfo) -> SerialPortInfo
fn from_wire(wire: SerialPortInfo) -> SerialPortInfo
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SerialPortInfo> for SerialPortInfo
impl FromWireRef<SerialPortInfo> for SerialPortInfo
Sourcefn from_wire_ref(wire: &SerialPortInfo) -> SerialPortInfo
fn from_wire_ref(wire: &SerialPortInfo) -> SerialPortInfo
Converts the given reference to this type.
Sourceimpl Hash for SerialPortInfo
impl Hash for SerialPortInfo
Sourceimpl Ord for SerialPortInfo
impl Ord for SerialPortInfo
Sourcefn cmp(&self, other: &SerialPortInfo) -> Ordering
fn cmp(&self, other: &SerialPortInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for SerialPortInfo
impl PartialEq for SerialPortInfo
Sourceimpl PartialOrd for SerialPortInfo
impl PartialOrd for SerialPortInfo
impl StructuralPartialEq for SerialPortInfo