#[repr(C)]pub struct DeviceProxyGetChannelRequest {
pub req: ServerEnd<Device, Channel>,
}Expand description
The wire type corresponding to DeviceProxyGetChannelRequest.
Fields
req: ServerEnd<Device, Channel>Trait Implementations
Sourceimpl Constrained for DeviceProxyGetChannelRequest
impl Constrained for DeviceProxyGetChannelRequest
Sourceimpl Debug for DeviceProxyGetChannelRequest
impl Debug for DeviceProxyGetChannelRequest
Sourceimpl<___D> Decode<___D> for DeviceProxyGetChannelRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceProxyGetChannelRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceProxyGetChannelRequest, ___E> for DeviceProxyGetChannelRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceProxyGetChannelRequest, ___E> for DeviceProxyGetChannelRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceProxyGetChannelRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceProxyGetChannelRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProxyGetChannelRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProxyGetChannelRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceProxyGetChannelRequest, ___E> for DeviceProxyGetChannelRequest<T0>
impl<___E, T0> Encode<DeviceProxyGetChannelRequest, ___E> for DeviceProxyGetChannelRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProxyGetChannelRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProxyGetChannelRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceProxyGetChannelRequest> for DeviceProxyGetChannelRequest
impl FromWire<DeviceProxyGetChannelRequest> for DeviceProxyGetChannelRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceProxyGetChannelRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceProxyGetChannelRequest, Self>
Sourcefn from_wire(wire: DeviceProxyGetChannelRequest) -> Self
fn from_wire(wire: DeviceProxyGetChannelRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceProxyGetChannelRequest
impl IntoNatural for DeviceProxyGetChannelRequest
Sourcetype Natural = DeviceProxyGetChannelRequest
type Natural = DeviceProxyGetChannelRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceProxyGetChannelRequest
impl Wire for DeviceProxyGetChannelRequest
Sourcetype Narrowed<'de> = DeviceProxyGetChannelRequest
type Narrowed<'de> = DeviceProxyGetChannelRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.