#[repr(C)]pub struct SerialPortInfo {
pub serial_class: Class,
pub serial_vid: Uint32,
pub serial_pid: Uint32,
}Expand description
The wire type corresponding to SerialPortInfo.
Fields
serial_class: Classserial_vid: Uint32serial_pid: Uint32Trait Implementations
Sourceimpl Clone for SerialPortInfo
impl Clone for SerialPortInfo
Sourcefn clone(&self) -> SerialPortInfo
fn clone(&self) -> SerialPortInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SerialPortInfo
impl Constrained for SerialPortInfo
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SerialPortInfo>,
_: <SerialPortInfo as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SerialPortInfo>, _: <SerialPortInfo as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SerialPortInfo
impl Debug for SerialPortInfo
Sourceimpl<___D> Decode<___D> for SerialPortInfowhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SerialPortInfowhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SerialPortInfo, ___E> for SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SerialPortInfo, ___E> for SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SerialPortInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SerialPortInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<SerialPortInfo, ___E> for &'a SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SerialPortInfo, ___E> for &'a SerialPortInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SerialPortInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SerialPortInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<SerialPortInfo, ___E> for SerialPortInfo<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<SerialPortInfo, ___E> for SerialPortInfo<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SerialPortInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SerialPortInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SerialPortInfo> for SerialPortInfo
impl FromWire<SerialPortInfo> for SerialPortInfo
Sourcefn from_wire(wire: SerialPortInfo) -> SerialPortInfo
fn from_wire(wire: SerialPortInfo) -> SerialPortInfo
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SerialPortInfo> for SerialPortInfo
impl FromWireRef<SerialPortInfo> for SerialPortInfo
Sourcefn from_wire_ref(wire: &SerialPortInfo) -> SerialPortInfo
fn from_wire_ref(wire: &SerialPortInfo) -> SerialPortInfo
Converts the given reference to this type.
Sourceimpl IntoNatural for SerialPortInfo
impl IntoNatural for SerialPortInfo
Sourcetype Natural = SerialPortInfo
type Natural = SerialPortInfo
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SerialPortInfo
impl Wire for SerialPortInfo
Sourcetype Narrowed<'de> = SerialPortInfo
type Narrowed<'de> = SerialPortInfo
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SerialPortInfo>)
fn zero_padding(out_: &mut MaybeUninit<SerialPortInfo>)
Writes zeroes to the padding for this type, if any.